@@ -45,30 +45,42 @@ class MediaPool():
     def add_sub_folder(self, folder: Folder, name: str) -> Folder:
         return Folder(self.media_pool.AddSubFolder(folder, name))
 
-    @dispatch(List[MediaPoolItem])
-    def append_to_timeline(self, clips: List[MediaPoolItem]) -> List[TimelineItem]: # type: ignore
-        timeline_item_list = []
-        for timeline_item in self.media_pool.AppendToTimeline([clip.media_pool_item for clip in clips]):
-            timeline_item_list.append(TimelineItem(timeline_item))
-        return timeline_item_list
+    # @dispatch(List[MediaPoolItem])
+    # type: ignore
+    def append_to_timeline(self, clips: List[MediaPoolItem]) -> List[TimelineItem]:
+        if type(clips[0]) is MediaPoolItem:
+            temp_list = self.media_pool.AppendToTimeline(
+                [clip.media_pool_item for clip in clips])
+        elif type(clips[0]) is ClipInfo:
+            temp_list = self.media_pool.AppendToTimeline(
+                [asdict(ClipInfo) for clip in clips])
 
-    @dispatch(List[ClipInfo])
-    def append_to_timeline(self, clips: List[ClipInfo]) -> List[TimelineItem]:
-        timeline_item_list = []
-        for timeline_item in self.media_pool.AppendToTimeline([asdict(ClipInfo) for ClipInfo in clips]):
-            timeline_item_list.append(TimelineItem(timeline_item))
-        return timeline_item_list
+        # timeline_item_list = []
+        # for timeline_item in temp_list:
+        #     timeline_item_list.append(TimelineItem(timeline_item))
+        return [TimelineItem(timeline_item) for timeline_item in temp_list]
+
+    # @dispatch(List[ClipInfo])
+    # def append_to_timeline(self, clips: List[ClipInfo]) -> List[TimelineItem]:
+    #     timeline_item_list = []
+    #     for timeline_item in self.media_pool.AppendToTimeline([asdict(ClipInfo) for ClipInfo in clips]):
+    #         timeline_item_list.append(TimelineItem(timeline_item))
+    #     return timeline_item_list
 
     def create_empty_timeline(self, name) -> Timeline:
         return Timeline(self.media_pool.CreateEmptyTimeline(name))
 
-    @dispatch(str, Iterable)
-    def create_timeline_from_clips(self, name: str, clips: List[MediaPoolItem]) -> Timeline:  # type: ignore
-        return Timeline(self.media_pool.CreateTimelineFromClips(name, [clip.media_pool_item for clip in clips]))
+    # @dispatch(str, Iterable)
+    # type: ignore
+    def create_timeline_from_clips(self, name: str, clips) -> Timeline:
+        if type(clips[0]) is MediaPoolItem:
+            return Timeline(self.media_pool.CreateTimelineFromClips(name, [clip.media_pool_item for clip in clips]))
+        elif type(clips[0]) is ClipInfo:
+            return Timeline(self.media_pool.CreateTimelineFromClips(name, [asdict(ClipInfo) for clip in clips]))
 
-    @dispatch(str, List[ClipInfo])
-    def create_timeline_from_clips(self, name: str, clip_infos: List[ClipInfo]) -> Timeline:
-        return self.media_pool.CreateTimelineFromClips(name, [asdict(ClipInfo) for ClipInfo in clip_infos]) 
+    # @dispatch(str, List[ClipInfo])
+    # def create_timeline_from_clips(self, name: str, clip_infos: List[ClipInfo]) -> Timeline:
+    #     return self.media_pool.CreateTimelineFromClips(name, [asdict(ClipInfo) for ClipInfo in clip_infos])
 
     def delete_clip_mattes(self, media_pool_item: MediaPoolItem, paths: List[str]) -> bool:
         return self.media_pool.DeleteClipMattes(media_pool_item, paths)
@@ -103,12 +115,13 @@ class MediaPool():
             media_pool_item_list.append(MediaPoolItem(media_pool_item))
         return media_pool_item_list
 
-    #@dispatch(List[str])
-    def import_media(self, file_paths: List[str]) -> List[MediaPoolItem]: # type: ignore
-        media_pool_item_list = []
-        for media_pool_item in self.media_pool.ImportMedia(file_paths):
-            media_pool_item_list.append(MediaPoolItem(media_pool_item))
-        return media_pool_item_list
+    # @dispatch(List[str])
+    # type: ignore
+    def import_media(self, file_paths: List[str]) -> List[MediaPoolItem]:
+        # media_pool_item_list = []
+        # for media_pool_item in self.media_pool.ImportMedia(file_paths):
+        #     media_pool_item_list.append(MediaPoolItem(media_pool_item))
+        return [MediaPoolItem(media_pool_item) for media_pool_item in self.media_pool.ImportMedia(file_paths)]
 
     # @dispatch(List[dict])
     # def import_media(self, clip_info: List[dict]) -> List[MediaPoolItem]:
